@@ -1,10 +1,7 @@
-#$Id$
+#$Id: Constrain.pm 38 2012-11-20 03:07:52Z maj $
 package REST::Neo4p::Constrain;
 use base 'Exporter';
 use REST::Neo4p::Constraint qw(:all);
-use REST::Neo4p::Constraint::Property;
-use REST::Neo4p::Constraint::Relationship;
-use REST::Neo4p::Constraint::RelationshipType;
 use REST::Neo4p::Exceptions;
 use strict;
 use warnings;
@@ -12,7 +9,7 @@ no warnings qw(once redefine);
 
 
 BEGIN {
-  $REST::Neo4p::Constrain::VERSION = '0.4000';
+  $REST::Neo4p::Constrain::VERSION = '0.20';
 }
 our @EXPORT = qw(create_constraint drop_constraint constrain relax);
 our @VALIDATE = qw(validate_properties validate_relationship validate_relationship_type);
@@ -78,7 +75,7 @@ sub create_constraint {
 	REST::Neo4p::ConstraintSpecException->throw($e->message);
       }
       if ($e = Exception::Class->caught()) {
-	(ref $e && $e->can("rethrow")) ? $e->rethrow : die $e;
+	ref $e ? $e->rethrow : die $e;
       }
       last;
     };
@@ -99,7 +96,7 @@ sub create_constraint {
 	REST::Neo4p::ConstraintSpecException->throw($e->message);
       }
       if ($e = Exception::Class->caught()) {
-	(ref $e && $e->can("rethrow")) ? $e->rethrow : die $e;
+	ref $e ? $e->rethrow : die $e;
       }
       last;
     };
@@ -122,7 +119,7 @@ sub create_constraint {
 	REST::Neo4p::ConstraintSpecException->throw($e->message);
       }
       if ($e = Exception::Class->caught()) {
-	(ref $e && $e->can("rethrow")) ? $e->rethrow : die $e;
+	ref $e ? $e->rethrow : die $e;
       }
       last;
     };
@@ -144,7 +141,7 @@ sub create_constraint {
 	REST::Neo4p::ConstraintSpecException->throw($e->message);
       }
       if ($e = Exception::Class->caught()) {
-	(ref $e && $e->can("rethrow")) ? $e->rethrow : die $e;
+	ref $e ? $e->rethrow : die $e;
       }
       last;
     };
@@ -280,7 +277,7 @@ REST::Neo4p::Constrain - Create and apply Neo4j app-level constraints
  );
 
  create_constraint(
-  tag => 'loves',
+  tag => 'ignore',
   type => 'relationship',
   rtype => 'LOVES',
   constraints =>  [{ pet => 'owner' },
@@ -443,7 +440,7 @@ the database
 
 =back
 
-The L</SYNOPSIS> is a full example.
+L<Below|/An Example> is an example.
 
 =head2 Types of Constraints
 
@@ -460,7 +457,7 @@ must not) take.
 =item * Relationship property constraints
 
 A relationship property constraint specifies the presence/absence of
-properties, and can specify the allowable values a property must (or
+properties, and can specifiy the allowable values a property must (or
 must not) take. In addition, a relationship property constraint can be
 linked to a given relationship type, so that, e.g., the creation of a
 relationship of a given type can be forced to have specified
@@ -493,8 +490,7 @@ C<create_constraint> accepts a hash of parameters. The following are required:
                # constraint
   type => $type, # node_property|relationship_property|
                  # relationship|relationship_type
-  priority => $integer_priority, # to determine which constraints
-                                 # are evaluated first during validation
+
   constraints => $constraints, # a reference that depends on the
                              # constraint type, see below
  );
@@ -621,7 +617,7 @@ The C<condition> parameter can take the following values:
 L<C<create_constraint()>|/create_constraint()> registers the created
 constraint so that it is included in all relevant validations.
 
-L<C<drop_constraint()>|/drop_constraint()> deregisters and removes the
+L<C<drop_constraint()>|/drop_constraint> deregisters and removes the
 constraint specified by its tag:
 
  drop_constraint('owner');
@@ -708,7 +704,7 @@ Deregisters a constraint identified by its tag. Returns the constraint object.
 
 constrain() forces L<REST::Neo4p> constructors and property setters to
 comply with the currently registered
-constraints. L<REST::Neo4p::Exceptions|REST::Neo4p::ConstraintException>s
+constraints. L<REST::Neo4p::ConstraintException|REST::Neo4p::Exceptions>s
 are thrown if constraints are not met.
 
 relax() turns off the automatic validation of constrain().
@@ -728,7 +724,7 @@ Import with
 
 =over
 
-=item serialize_constraints()
+=item seralize_constraints()
 
  open $f, ">constraints.json";
  print $f serialize_constraints();
@@ -764,7 +760,7 @@ Import with
 
  validate_properties( $node_object )
  validate_properties( $relationship_object );
- validate_properties( { name => 'Steve', instrument => 'banjo' } );
+ validate_properties( { name => 'Steve', instrument => 'banjo } );
 
 =item validate_relationship()
 
@@ -795,7 +791,7 @@ L<REST::Neo4p>, L<REST::Neo4p::Constraint>
 
 =head1 LICENSE
 
-Copyright (c) 2012-2020 Mark A. Jensen. This program is free software; you
+Copyright (c) 2012 Mark A. Jensen. This program is free software; you
 can redistribute it and/or modify it under the same terms as Perl
 itself.
 
