@@ -1,8 +1,11 @@
-#$Id$
+#$Id: Constraint.pm 39 2012-11-21 04:26:01Z maj $
 package REST::Neo4p::Constraint;
 use base 'Exporter';
 use REST::Neo4p;
 use REST::Neo4p::Exceptions;
+use REST::Neo4p::Constraint::Property;
+use REST::Neo4p::Constraint::Relationship;
+use REST::Neo4p::Constraint::RelationshipType;
 use JSON;
 use Data::Dumper;
 
@@ -19,7 +22,7 @@ our %EXPORT_TAGS = (
   all => [@EXPORT,@EXPORT_OK]
 );
 
-our $jobj = JSON->new->utf8;
+our $jobj = JSON->new();
 $jobj->allow_blessed(1);
 $jobj->convert_blessed(1);
 my $regex_to_json = sub {
@@ -31,7 +34,7 @@ my $regex_to_json = sub {
 };
 
 BEGIN {
-  $REST::Neo4p::Constraint::VERSION = '0.4000';
+  $REST::Neo4p::Constraint::VERSION = "0.20";
 }
 
 # valid constraint types
@@ -120,9 +123,9 @@ sub _fix_constraints {
   if (ref eq 'HASH') {
     while (my ($k, $v) = each %$_) {
       if ($v && ($v =~ /^qr\//)) {
-	 if ($v =~ /\(\?(\^|-[a-z]+):.*\)/) {
-	   $v =~ s{/\(\?(\^|-[a-z]+):}{/}; # kludge - eval wants to wrap (?:^...) around a qr string
-	   $v =~ s{\)/}{/}; # kludge -      even if one is there already
+	 if ($v =~ /\(\?\^:.*\)/) {
+	   $v =~ s|/\(\?\^:|/|; # kludge - eval wants to wrap (?:^...) around a qr string
+	   $v =~ s|\)/|/|; # kludge -      even if one is there already
 	 }
 	$_->{$k} = eval $v; # replace with Regexp
       }
@@ -381,18 +384,8 @@ Get a hash of all registered constraint objects, keyed by constraint tag.
 
 =item condition()
 
-=item set_condition()
-
- $reln_c->set_condition('only');
-
-Set the group condition for the constraint. See subclass pod for details.
-
 =item priority()
 
-=item set_priority()
-
- $node_pc->set_priority(10);
-
 Constraints with larger priority values are checked before those with
 smaller values by the L<C<validate_*()>|/Functional interface for
 validation> functions.
@@ -401,6 +394,20 @@ validation> functions.
 
 Returns the hashref of constraints. Format depends on the subclass.
 
+=item set_condition()
+
+ $reln_c->set_condition('only');
+
+Set the group condition for the constraint. See subclass pod for details.
+
+=item set_priority()
+
+ $node_pc->set_priority(10);
+
+Set the constraint's priority. Constraints with higher priority will
+be checked before constraints with lower priority in the
+L<validate_*()|/Functional interface for validation> functions.
+
 =item add_constraint()
 
  $node_pc->add_constraint( 'warning_level' => qr/^[0-9]$/ );
@@ -427,7 +434,7 @@ constraint object. See subclass pod for details.
 
  validate_properties( $node_object )
  validate_properties( $relationship_object );
- validate_properties( { name => 'Steve', instrument => 'banjo' } );
+ validate_properties( { name => 'Steve', instrument => 'banjo } );
 
 =item validate_relationship()
 
@@ -442,8 +449,6 @@ constraint object. See subclass pod for details.
 
  validate_relationship_type( 'avoids' )
 
-=back
-
 Functional interface. Returns the registered constraint object with
 the highest priority that the argument satisfies, or false if none is
 satisfied.
@@ -456,6 +461,8 @@ They can also be exported from L<REST::Neo4p::Constrain>:
 
  use REST::Neo4p::Constrain qw(:validate)
 
+=back
+
 =head2 Serializing and loading constraints
 
 =over
@@ -495,7 +502,7 @@ L<REST::Neo4p::Constraint::RelationshipType>. L<REST::Neo4p::Node>, L<REST::Neo4
 
 =head1 LICENSE
 
-Copyright (c) 2012-2020 Mark A. Jensen. This program is free software; you
+Copyright (c) 2012 Mark A. Jensen. This program is free software; you
 can redistribute it and/or modify it under the same terms as Perl
 itself.
 
