@@ -1,11 +1,11 @@
-#$Id$
+#$Id: Property.pm 39 2012-11-21 04:26:01Z maj $
 package REST::Neo4p::Constraint::Property;
 use base 'REST::Neo4p::Constraint';
 use strict;
 use warnings;
 
 BEGIN {
-  $REST::Neo4p::Constraint::Property::VERSION = '0.4000';
+  $REST::Neo4p::Constraint::Property::VERSION = '0.20';
 }
 
 sub new_from_constraint_hash {
@@ -188,10 +188,6 @@ package REST::Neo4p::Constraint::NodeProperty;
 use base 'REST::Neo4p::Constraint::Property';
 use strict;
 use warnings;
-BEGIN {
-  $REST::Neo4p::Constraint::NodeProperty::VERSION='0.4000';
-  $REST::Neo4p::Constraint::NodeProperty::VERSION='0.4000';
-}
 
 sub new {
   my $class = shift;
@@ -216,10 +212,6 @@ use base 'REST::Neo4p::Constraint::Property';
 use strict;
 use warnings;
 
-BEGIN {
-  $REST::Neo4p::Constraint::RelationshipProperty::VERSION='0.4000';
-  $REST::Neo4p::Constraint::RelationshipProperty::VERSION='0.4000';
-}
 # relationship_type is added as a pseudoproperty
 
 sub new {
@@ -255,21 +247,7 @@ REST::Neo4p::Constraint::Property - Neo4j Property Constraints
 
 =head1 SYNOPSIS
 
- # use REST::Neo4p::Constrain, it's nicer
-
- $npc = REST::Neo4p::Constraint::NodeProperty->new(
-   'soldier' => { _condition => 'all',
-                  _priority => 1,
-                  name => '',
-                  rank => [],
-                  serial_number => qr/^[0-9]+$/,
-                  army_of => 'one' }
-  );
-
- $rpc = REST::Neo4p::Constraint::RelationshipProperty->new(
-  'position' => { _condition => 'only',
-                  position => qr/[0-9]+/ }
-  );
+See L<REST::Neo4p::Constraint>.
 
 =head1 DESCRIPTION
 
@@ -308,12 +286,8 @@ Constraint hash specification:
 
 =item add_constraint()
 
- $np->add_constraint( optional_accessory => [qw(tie ascot boutonniere)] );
-
 =item remove_constraint()
 
- $np->remove_constraint( 'unneeded_property' );
-
 =item tag()
 
 Returns the constraint tag.
@@ -366,7 +340,7 @@ L<REST::Neo4p::Constraint::RelationshipType>.
 
 =head1 LICENSE
 
-Copyright (c) 2012-2020 Mark A. Jensen. This program is free software; you
+Copyright (c) 2012 Mark A. Jensen. This program is free software; you
 can redistribute it and/or modify it under the same terms as Perl
 itself.
 
