@@ -1,11 +1,11 @@
-#$Id$
+#$Id: Relationship.pm 39 2012-11-21 04:26:01Z maj $
 package REST::Neo4p::Constraint::Relationship;
 use base 'REST::Neo4p::Constraint';
 use strict;
 use warnings;
 
 BEGIN {
-  $REST::Neo4p::Constraint::Relationship::VERSION = '0.4000';
+  $REST::Neo4p::Constraint::Relationship::VERSION = '0.20';
 }
 
 sub new {
@@ -162,17 +162,7 @@ REST::Neo4p::Constraint::Relationship - Neo4j Relationship Constraints
 
 =head1 SYNOPSIS
 
- # use REST::Neo4p::Constrain, it's nicer
-
- $rc = REST::Neo4p::Constraint::Relationship->new(
-   'allowed_contains_relns' => 
-     { _condition => 'only',
-       _relationship_type => 'contains',
-       _priority => 0,
-       _descriptors  => [ {'module' => 'method'},
-                          {'module' => 'variable'},
-                          {'method' => 'variable'} ] }
-   );
+See L<REST::Neo4p::Constraint>.
 
 =head1 DESCRIPTION
 
@@ -196,18 +186,14 @@ Constraint hash specification:
 
 =item new()
 
- $rc = $REST::Neo4p::Constraint::Relationship->new(
+ $r = $REST::Neo4p::Constraint::Relationship->new(
         $tag => $constraint_hash
       );
 
 =item add_constraint()
 
- $rc->add_constraint( { 'star' => 'planet' });
-
 =item remove_constraint()
 
- $rc->remove_constraint( { 'developer' => 'parole_officer' } );
-
 =item tag()
 
 Returns the constraint tag.
@@ -269,7 +255,7 @@ L<REST::Neo4p::Constraint::RelationshipType>.
 
 =head1 LICENSE
 
-Copyright (c) 2012-2020 Mark A. Jensen. This program is free software; you
+Copyright (c) 2012 Mark A. Jensen. This program is free software; you
 can redistribute it and/or modify it under the same terms as Perl
 itself.
 
