@@ -1,11 +1,11 @@
-#$Id$
+#$Id: RelationshipType.pm 39 2012-11-21 04:26:01Z maj $
 package REST::Neo4p::Constraint::RelationshipType;
 use base 'REST::Neo4p::Constraint';
 use strict;
 use warnings;
 
 BEGIN {
-  $REST::Neo4p::Constraint::RelationshipType::VERSION = '0.4000';
+  $REST::Neo4p::Constraint::RelationshipType::VERSION = "0.20";
 }
 
 sub new {
@@ -104,13 +104,7 @@ REST::Neo4p::Constraint::RelationshipType - Neo4j Relationship Type Constraints
 
 =head1 SYNOPSIS
 
- # use REST::Neo4p::Constrain, it's nicer
-
- $rtc = REST::Neo4p::Constraint::RelationshipType->new(
-  'allowed_reln_types' =>
-    { _condition => 'only', 
-      _type_list => [qw(contains has)] }
-  );
+See L<REST::Neo4p::Constraint>.
 
 =head1 DESCRIPTION
 
@@ -121,11 +115,15 @@ use.
 Constraint hash specification:
 
  { 
-   _condition => <'only'|'none'>,
-   _priority => <integer priority>,
+  _condition => <'only'|'none'>,
+  _priority => <integer priority>,
    _type_list => [ 'type_name_1', 'type_name_2', ...]  }
  }
 
+
+must meet only these conditions - whitelist - only (cannot match unless matching type is enumerated)
+must not meet any conditions - blacklist - none
+
 =head1 METHODS
 
 =over
@@ -140,16 +138,10 @@ Constraint hash specification:
 
 =item add_types()
 
- $rc->add_constraint('new_type');
- $rc->add_type('new_type');
-
 =item remove_constraint()
 
 =item remove_type()
 
- $rc->remove_constraint('old_type');
- $rc->remove_type('old_type');
-
 =item tag()
 
 Returns the constraint tag.
@@ -158,6 +150,10 @@ Returns the constraint tag.
 
 Returns the constraint type ('relationship_type').
 
+=item rtype()
+
+The relationship type to which this constraint applies.
+
 =item condition()
 
 =item set_condition()
@@ -200,7 +196,7 @@ L<REST::Neo4p::Constraint::RelationshipType>.
 
 =head1 LICENSE
 
-Copyright (c) 2012-2020 Mark A. Jensen. This program is free software; you
+Copyright (c) 2012 Mark A. Jensen. This program is free software; you
 can redistribute it and/or modify it under the same terms as Perl
 itself.
 
